@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package App::Nopaste; # git description: 1.006-9-g41755c7
+package App::Nopaste; # git description: 1.010-5-ge64d42a
 # ABSTRACT: Easy access to any pastebin
 # KEYWORDS: application executable paste output pastebin debugging
 
-our $VERSION = '1.007';
+our $VERSION = '1.011';
 
 use 5.008003;
 use Module::Pluggable search_path => 'App::Nopaste::Service', sub_name => '_plugins';
@@ -101,7 +101,7 @@ App::Nopaste - Easy access to any pastebin
 
 =head1 VERSION
 
-version 1.007
+version 1.011
 
 =head1 SYNOPSIS
 
@@ -203,7 +203,7 @@ Shawn M Moore, <sartak@gmail.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Shawn M Moore Karen Etheridge Thomas Sibley François Gannaz Ricardo Signes Justin Hunter Kevin Falcone Zoffix Znet Sergey Romanov David Golden Jesse Luehrs Dean Hamstead Rafael Kitover Ævar Arnfjörð Bjarmason Сергей Романов Arthur Axel 'fREW' Schmidt יובל קוג'מן (Yuval Kogman) Darian Anthony Patrick Bremner J. Shultz Graham Knop Jason Mills John Goulah Maximilian Gass Sebastian Paaske Tørholm Tatsuhiko Miyagawa Zakariyya Mughal gregor herrmann vti
+=for stopwords Shawn M Moore Karen Etheridge Thomas Sibley François Gannaz Ricardo Signes Justin Hunter Kevin Falcone Zoffix Znet Sergey Romanov David Golden Jesse Luehrs Dean Hamstead Rafael Kitover gregor herrmann vti Ævar Arnfjörð Bjarmason Сергей Романов Andrew Rodland יובל קוג'מן (Yuval Kogman) Arthur Axel 'fREW' Schmidt Dan Book Darian Anthony Patrick Bremner J. Shultz Graham Knop Jason Mills John Goulah Maximilian Gass Sebastian Paaske Tørholm Tatsuhiko Miyagawa Zakariyya Mughal
 
 =over 4
 
@@ -261,6 +261,14 @@ Rafael Kitover <rkitover@cpan.org>
 
 =item *
 
+gregor herrmann <gregoa@debian.org>
+
+=item *
+
+vti <viacheslav.t@gmail.com>
+
+=item *
+
 Ævar Arnfjörð Bjarmason <avarab@gmail.com>
 
 =item *
@@ -269,7 +277,7 @@ Rafael Kitover <rkitover@cpan.org>
 
 =item *
 
-Arthur Axel 'fREW' Schmidt <frioux@gmail.com>
+Andrew Rodland <andrew@cleverdomain.org>
 
 =item *
 
@@ -277,6 +285,14 @@ Arthur Axel 'fREW' Schmidt <frioux@gmail.com>
 
 =item *
 
+Arthur Axel 'fREW' Schmidt <frioux@gmail.com>
+
+=item *
+
+Dan Book <grinnz@gmail.com>
+
+=item *
+
 Darian Anthony Patrick <dap@darianpatrick.com>
 
 =item *
@@ -315,14 +331,6 @@ Tatsuhiko Miyagawa <miyagawa@bulknews.net>
 
 Zakariyya Mughal <zaki.mughal@gmail.com>
 
-=item *
-
-gregor herrmann <gregoa@debian.org>
-
-=item *
-
-vti <viacheslav.t@gmail.com>
-
 =back
 
 =head1 COPYRIGHT AND LICENSE
