@@ -2,12 +2,14 @@ use strict;
 use warnings;
 package App::Nopaste::Command;
 # ABSTRACT: command-line utility for L<App::Nopaste>
-our $VERSION = '1.004';
+
+our $VERSION = '1.011';
+
 use Getopt::Long::Descriptive ();
 
 use App::Nopaste;
 use Module::Runtime 'use_module';
-use namespace::clean;
+use namespace::clean 0.19;
 
 sub new_with_options {
     my $class = shift;
@@ -157,7 +159,7 @@ App::Nopaste::Command - command-line utility for L<App::Nopaste>
 
 =head1 VERSION
 
-version 1.004
+version 1.011
 
 =head1 DESCRIPTION
 
@@ -217,6 +219,11 @@ If specified, the paste access will be restricted to those that know the URL.
 
 If specified, do not warn or complain about broken services.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
 =head1 AUTHOR
 
 Shawn M Moore, <sartak@gmail.com>
