@@ -2,7 +2,9 @@ use strict;
 use warnings;
 package App::Nopaste::Service;
 # ABSTRACT: base class for nopaste services
-our $VERSION = '1.004';
+
+our $VERSION = '1.011';
+
 use WWW::Mechanize;
 
 sub available         { 1 }
@@ -107,12 +109,12 @@ App::Nopaste::Service - base class for nopaste services
 
 =head1 VERSION
 
-version 1.004
+version 1.011
 
 =head1 SYNOPSIS
 
     package App::Nopaste::Service::Shadowcat;
-    use base 'App::Nopaste::Service';
+    use parent 'App::Nopaste::Service';
 
     sub uri { "http://paste.scsys.co.uk/" }
 
@@ -185,6 +187,11 @@ pasted text.
 
 Shawn M Moore, C<< <sartak at gmail.com> >>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
 =head1 AUTHOR
 
 Shawn M Moore, <sartak@gmail.com>
